@@ -6,17 +6,39 @@
 using namespace std;
 
 
-TCPMessageClient::TCPMessageClient(asio::io_service& io_service, const char * host, const char * port): ioservice(io_service), resolver(ioservice), socket(ioservice)
+TCPMessageClient::TCPMessageClient(asio::io_service& io_service, const char * host, const char * port):
+  ioservice(io_service),
+  timer(ioservice),
+  resolver(ioservice),
+  socket(ioservice),
+  m_host(host),
+  m_port(port)
 {
-  asio::ip::tcp::resolver::query query(host, port);
+  startResolver();
+}
+
+TCPMessageClient::~TCPMessageClient()
+{
+}
+
+
+void TCPMessageClient::startResolver()
+{
+  asio::ip::tcp::resolver::query query(m_host, m_port);
   stopAfterOneReceivedMessage=false;
   sendQueueCurrentlySending=false;
   resolver.async_resolve(query,
                          boost::bind(&TCPMessageClient::handleResolve, this, asio::placeholders::error,asio::placeholders::iterator));
 }
 
-TCPMessageClient::~TCPMessageClient()
+
+void TCPMessageClient::closeAndScheduleResolve()
 {
+  socket.close();
+
+  boost::posix_time::time_duration expiry_time=boost::posix_time::seconds(3);
+  timer.expires_from_now(expiry_time);
+  timer.async_wait(boost::bind(&TCPMessageClient::startResolver, this));
 }
 
 
@@ -33,7 +55,8 @@ void TCPMessageClient::handleResolve(const asio::error_code& err, asio::ip::tcp:
   }
   else
   {
-    std::cout << "Error: " << err.message() << endl;
+    std::cout << "TCPMessageClient::handleResolve error: " << err.message() << endl;
+    closeAndScheduleResolve();
   }
 }
 
@@ -61,7 +84,9 @@ void TCPMessageClient::handleConnect(const asio::error_code& err, asio::ip::tcp:
   }
   else
   {
-    std::cout << "Error: " << err.message() << endl;
+    std::cout << "TCPMessageClient::handleConnect error: " << err.message() << endl;
+    connectionNotReadySignal();
+    closeAndScheduleResolve();
   }
 }
 
@@ -107,6 +132,8 @@ void TCPMessageClient::handleWriteMessage(const asio::error_code& err)
   else
   {
     cout << "TCPMessageClient::handleWriteMessage error: " << err.message() << endl;
+    connectionNotReadySignal();
+    closeAndScheduleResolve();
   }
 }
 
@@ -128,7 +155,9 @@ void TCPMessageClient::handleReadMessageSize(const asio::error_code& err, size_t
   }
   else
   {
-    std::cout << "Error: " << err << endl;
+    std::cout << "TCPMessageClient::handleReadMessageSize error: " << err << endl;
+    connectionNotReadySignal();
+    closeAndScheduleResolve();
   }
 }
 
@@ -152,7 +181,9 @@ void TCPMessageClient::handleReadMessage(const asio::error_code& err, size_t len
   }
   else if (err != asio::error::eof)
   {
-    std::cout << "Error: " << err << endl;
+    std::cout << "TCPMessageClient::handleReadMessage error: " << err << endl;
+    connectionNotReadySignal();
+    closeAndScheduleResolve();
   }
 }
 
