@@ -3,10 +3,20 @@
 
 
 #include <asio.hpp>
+#include <boost/date_time/posix_time/posix_time.hpp>
 #include <boost/signal.hpp>
 #include "messageclient.h"
 
-
+// class TCPMessageClient
+//    actively tries to connect to a server
+//    and tries to reconnect to a server every the the  connection is interrupted
+//
+// There is no interface to start and stop a connection to the upper leyer code.
+//
+// Availability is signalized to upper layer by the signals
+//   connectionReadySignal
+// and
+//   connectioNotReadySignal
 class TCPMessageClient : public MessageClient
 {
 private:
@@ -15,6 +25,7 @@ private:
   asio::ip::tcp::resolver resolver;
   asio::ip::tcp::socket socket;
 
+  asio::deadline_timer timer;
 
   unsigned long messageSize;
   char data[maxMessageIOSize];
@@ -26,10 +37,15 @@ private:
   void handleReadMessage(const asio::error_code& err, size_t length);
 
   std::list<Message>  sendQueue;
+  void startResolver();
+  void closeAndScheduleResolve();
   bool sendQueueCurrentlySending;
   void startNewTransmission();
   void handleWriteMessage(const asio::error_code& err);
 
+  std::string m_host;
+  std::string m_port;
+
 public:
   TCPMessageClient(asio::io_service& io_service, const char * host, const char * port);
   ~TCPMessageClient();
