@@ -18,8 +18,7 @@ private:
 
 
   asio::ip::udp::socket socket;
-  enum { max_length = 16384 };
-  char data[max_length];
+  char data[maxMessageIOSize];
   void handleReceiveFrom(const asio::error_code& err, size_t length);
 
   std::list<Message>  sendQueue;
