@@ -3,13 +3,13 @@
 
 #include <asio.hpp>
 #include "messageserver.h"
+#include "messageioconst.h"
 
 
 class UDPMessageServer : public MessageServer
 {
 private:
-  enum { max_length = 16384 };
-  char data[max_length];
+  char data[maxMessageIOSize];
   asio::ip::udp::endpoint sender_endpoint;
 
   asio::io_service & ioservice;
@@ -19,7 +19,6 @@ private:
   void handleReceiveFrom(const asio::error_code& err, size_t length);
 
 public:
-  UDPMessageServer(asio::io_service& io_service, unsigned short port_num);
   UDPMessageServer(asio::io_service& io_service, const asio::ip::udp::endpoint & endpoint);
 };
 
