@@ -26,6 +26,7 @@ void TheTimerObjectAsio::timerExpiredEvent(const asio::error_code& err)
   }
   else
   {
+    timerActive=false;
     if (myHandlerBase)
     {
       (*myHandlerBase)();
@@ -36,12 +37,14 @@ void TheTimerObjectAsio::timerExpiredEvent(const asio::error_code& err)
 
 TheTimerObjectAsio::TheTimerObjectAsio(asio::io_service & ioservice) : ioservice(ioservice), timer(ioservice)
 {
+  timerActive=false;
   myHandlerBase=0;
 }
 
 
 TheTimerObjectAsio::~TheTimerObjectAsio()
 {
+  stop();
 }
 
 
@@ -50,6 +53,7 @@ void TheTimerObjectAsio::startAlarmAt(const boost::posix_time::ptime & time, Tim
   myHandlerBase=handler;
   timer.expires_at(time);
   timer.async_wait(boost::bind(&TheTimerObjectAsio::timerExpiredEvent, this, asio::placeholders::error));
+  timerActive=true;
 }
 
 
@@ -58,11 +62,22 @@ void TheTimerObjectAsio::startAlarmAfter(const boost::posix_time::time_duration
   myHandlerBase=handler;
   timer.expires_from_now(expiry_time);
   timer.async_wait(boost::bind(&TheTimerObjectAsio::timerExpiredEvent, this, asio::placeholders::error));
+  timerActive=true;
 }
 
 
 void TheTimerObjectAsio::stop()
 {
-  timer.cancel();
+  if (timerActive)
+  {
+    timer.cancel();
+    timerActive=false;
+  }
 }
 
+bool TheTimerObjectAsio::isRunning()
+{
+  return timerActive;
+}
+
+
