@@ -23,6 +23,8 @@ class TheTimerObjectAsio : public TheTimerObjectBase
 {
 private:
   asio::io_service & ioservice;
+
+  bool timerActive;
   asio::deadline_timer timer;
 
   void timerExpiredEvent(const asio::error_code& err);
@@ -34,6 +36,7 @@ public:
   void startAlarmAt(const boost::posix_time::ptime & time, TimerEventHandlerBase * handler);
   void startAlarmAfter(const boost::posix_time::time_duration & expiry_time, TimerEventHandlerBase * handler);
   void stop();
+  bool isRunning();
 };
 
 
