@@ -451,17 +451,11 @@ void SinfoCurses::printInit()
 
   win = newwin(0, 0, 0, 0);
   keypad(win, true);
+  wtimeout(win,10); // wgetch with delay: 10ms
+
 
   starty = 0;
   barState = 0;
-
-//nodelay(win,  FALSE); // blocking wgetch
-//wtimeout(win,100); // wgetch with delay: 100 ms
-//nodelay(win,TRUE); // non blocking wgetch
-
-//notimeout(win,  TRUE); // wgetch  does  not  set a timer.
-//notimeout(win,  FALSE); // wgetch  does  set a timer.
-
 //  printAll();
 }
 
@@ -620,25 +614,16 @@ void SinfoCurses::wsinfoListChangedSlot()
 void SinfoCurses::handle_read(const asio::error_code& e,
                               std::size_t bytes_transferred)
 {
-  // cout << "handle_read"  << endl;
-  // cout << "bytes_transferred"  << bytes_transferred << endl;
   if (!e)
   {
-    for (unsigned int i=0; i<bytes_transferred; i++)
-    {
-      ungetch(buffer_[i]);
-    }
-    // man:getch
-
     int key;
     while (ERR !=(key = wgetch(win)) )
     {
-      // cout << "keycode" << key << endl;
       keyCodeEvent(key);
     }
 
     printAll();
-    instream.async_read_some(asio::buffer(buffer_),
+    instream.async_read_some(asio::null_buffers(),
                              boost::bind(&SinfoCurses::handle_read, this,
                                          asio::placeholders::error,
                                          asio::placeholders::bytes_transferred));
@@ -651,7 +636,7 @@ SinfoCurses::SinfoCurses(asio::io_service& io_service, SinfoViewConfig & _config
 {
   barState=0;
 
-  instream.async_read_some(asio::buffer(buffer_),
+  instream.async_read_some(asio::null_buffers(),
                            boost::bind(&SinfoCurses::handle_read, this,
                                        asio::placeholders::error,
                                        asio::placeholders::bytes_transferred));
