@@ -5,7 +5,6 @@
 #include <list>
 #include <string>
 #include <asio.hpp>
-#include <boost/array.hpp>
 #ifdef HAVE_CURSES_H
 #include <curses.h>
 #endif
@@ -37,7 +36,6 @@ private:
   // keyboard handling   stdin => curses
   void handle_read(const asio::error_code& e, std::size_t bytes_transferred); // Handle completion of a read operation.
   asio::posix::stream_descriptor instream;                                    // stream on stdin
-  boost::array<char, 8192> buffer_;                                           // Buffer for incoming data.
 
   void keyCodeEvent(int key);
   void wsinfoListChangedSlot();
