@@ -3,7 +3,7 @@
 #include "messagebasictypes.h"
 #include "messagecomplextypes.h"
 #include "messagesinfotypes.h"
-#include "messagecontainertypes.h"
+#include "messagestlcontainertypes.h"
 #include "measureserver.h"
 #include "meminfometer.h"
 #include "loadavgmeter.h"
