@@ -3,10 +3,11 @@
 
 
 #include <asio.hpp>
-#include "cpustat.h"
-#include "netload.h"
-#include "diskload.h"
-#include "procinfo.h"
+#include "cpustatmeter.h"
+#include "netloadmeter.h"
+#include "diskloadmeter.h"
+#include "procinfometer.h"
+#include <boost/signal.hpp>
 
 
 class MeasureServer
@@ -15,14 +16,13 @@ private:
   asio::io_service & ioservice;
   asio::deadline_timer timer;
 
-  std::string bcast_address;
-
   unsigned long timeCounter;
 
   bool sendRestartFlag;
 
   ProcinfoMeter procinfoMeter;
   bool procinfonow;                 // flag that is set to send process infos if the load has changed dramatically
+  long listtop;
 
   CpustatMeter cpustatMeter;
   float lastidlepercent;
@@ -35,11 +35,13 @@ private:
 
 
 public:
-  MeasureServer(asio::io_service& io_service, const std::string & _bcast_address, const std::string & networkcard, const std::string & _marker);
+  MeasureServer(asio::io_service& io_service, const std::string & networkcard, const std::string & _marker, bool cmdlinemode, std::list < std::string > ignoreList, long listtop);
+  ~MeasureServer();
 
   void timerEvent();
   void restartCounterEvent();
 
+  boost::signal<void (Message&)> sendMeasurementSignal;
 
   void handle_timeout(); // asio part
 };
